import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 文档服务对象基类
 *
 * @export
 * @class EAMDocumentServiceBase
 * @extends {EntityServie}
 */
export default class EAMDocumentServiceBase extends EntityService {

    /**
     * Creates an instance of  EAMDocumentServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  EAMDocumentServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof EAMDocumentServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='eamdocument';
        this.APPDEKEY = 'eamdocumentid';
        this.APPDENAME = 'eamdocuments';
        this.APPDETEXT = 'eamdocumentname';
        this.APPNAME = 'assetmanagement';
        this.SYSTEMNAME = 'ibizassetmanagement';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMDocumentServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamassettype && context.eamdocument){
            let res:any = Http.getInstance().get(`/eamassettypes/${context.eamassettype}/eamdocuments/${context.eamdocument}/select`,isloading);
            
            return res;
        }
            let res:any = Http.getInstance().get(`/eamdocuments/${context.eamdocument}/select`,isloading);
            
            return res;
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMDocumentServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamassettype && true){
            let masterData:any = {};
            Object.assign(data,masterData);
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            let tempContext:any = JSON.parse(JSON.stringify(context));
            let res:any = await Http.getInstance().post(`/eamassettypes/${context.eamassettype}/eamdocuments`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/eamdocuments`,data,isloading);
        
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMDocumentServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamassettype && context.eamdocument){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().put(`/eamassettypes/${context.eamassettype}/eamdocuments/${context.eamdocument}`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/eamdocuments/${context.eamdocument}`,data,isloading);
            
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMDocumentServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamassettype && context.eamdocument){
            let res:any = Http.getInstance().delete(`/eamassettypes/${context.eamassettype}/eamdocuments/${context.eamdocument}`,isloading);
            return res;
        }
            let res:any = Http.getInstance().delete(`/eamdocuments/${context.eamdocument}`,isloading);
            return res;
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMDocumentServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamassettype && context.eamdocument){
            let res:any = await Http.getInstance().get(`/eamassettypes/${context.eamassettype}/eamdocuments/${context.eamdocument}`,isloading);
            
            return res;
        }
            let res:any = await Http.getInstance().get(`/eamdocuments/${context.eamdocument}`,isloading);
            
            return res;
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMDocumentServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamassettype && true){
            let res:any = await Http.getInstance().get(`/eamassettypes/${context.eamassettype}/eamdocuments/getdraft`,isloading);
            res.data.eamdocument = data.eamdocument;
            
            return res;
        }
        let res:any = await  Http.getInstance().get(`/eamdocuments/getdraft`,isloading);
        res.data.eamdocument = data.eamdocument;
        
        return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMDocumentServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamassettype && context.eamdocument){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/eamassettypes/${context.eamassettype}/eamdocuments/${context.eamdocument}/checkkey`,data,isloading);
            
            return res;
        }
            let res:any = Http.getInstance().post(`/eamdocuments/${context.eamdocument}/checkkey`,data,isloading);
            return res;
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMDocumentServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamassettype && context.eamdocument){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/eamassettypes/${context.eamassettype}/eamdocuments/${context.eamdocument}/save`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/eamdocuments/${context.eamdocument}/save`,data,isloading);
            
            return res;
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EAMDocumentServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.eamassettype && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            let res:any = Http.getInstance().get(`/eamassettypes/${context.eamassettype}/eamdocuments/fetchdefault`,tempData,isloading);
            return res;
        }
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/eamdocuments/fetchdefault`,tempData,isloading);
        return res;
    }
}